==> eam-wshub-proxyclient-11.4-5-sources.jar: net/datastream/schemas/mp_fields/BUDGET_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour BUDGET_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="BUDGET_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="BUDGETCODE" type="{http://schemas.datastream.net/MP_fields}CODE20_Type"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BUDGET_Type", propOrder = {
    "budgetcode",
    "description"
})
public class BUDGET_Type {

    @XmlElement(name = "BUDGETCODE", required = true)
    protected String budgetcode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Obtient la valeur de la propriété budgetcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBUDGETCODE() {
        return budgetcode;
    }

    /**
     * Définit la valeur de la propriété budgetcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBUDGETCODE(String value) {
        this.budgetcode = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/BUDGET_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for BUDGET_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="BUDGET_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="BUDGETCODE" type="{http://schemas.datastream.net/MP_fields}CODE20_Type"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BUDGET_Type", propOrder = {
    "budgetcode",
    "description"
})
public class BUDGET_Type {

    @XmlElement(name = "BUDGETCODE", required = true)
    protected String budgetcode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Gets the value of the budgetcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBUDGETCODE() {
        return budgetcode;
    }

    /**
     * Sets the value of the budgetcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBUDGETCODE(String value) {
        this.budgetcode = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}
